{
  config,
  pkgs,
  lib,
  options,
  specialArgs,
  modulesPath,
  wallpaper,
}: {
  nixpkgs.config.allowUnfreePredicate = _: true;

  home.stateVersion = "23.05";
  home.username = "kristian";
  home.homeDirectory = "/home/kristian";

  home.sessionVariables = {
    # Electron programms won't render correctly under wayland without this
    NIXOS_OZONE_WL = 1;
  };

  # Symlinks
  #home.file = {
  #  ".wallpaper".source = "${wallpaper.override { preset = "gruvbox-dark"; width = 3840; height = 2160;}}/share/wallpapers/nixos-wallpaper.png";
  #  #".wallpaper".source = ./wallpaper;
  #};

  # TODO: Change for Laptop
  targets.genericLinux.enable = false; # Enable on non-nixos ditros

  # Keyboard Layout
  home.keyboard.layout = "at"; # NOTE: Set by Hyprland config

  # Programs (additional programs)
  home.packages = import ./packages.nix {inherit pkgs;};

  # Services
  services = {
    copyq.enable = true;
  };

  # Programs
  programs = {
    home-manager.enable = true; # Allow home-manager to manage itself
    mpv.enable = true;
    obs-studio.enable = true;
    yt-dlp.enable = true;

    bash = import ./bash.nix {enable = true;};
    vscode = import ./vscode.nix {
      enable = true;
      inherit pkgs;
    };
    direnv = import ./direnv.nix {enable = true;};
    git = import ./git.nix {enable = true;};
    thunderbird = import ./thunderbird.nix {enable = true;};

    neovim = import ./nvim {
      enable = true;
      inherit pkgs;
    };

    firefox = import ./firefox.nix {
      enable = true;
      nur = config.nur;
    };
  };

  xdg.mimeApps = {
    enable = true;
    defaultApplications = {"video/*" = ["mpv.desktop"];};
  };

  # Gnome settings
  dconf.settings = import ./gnome.nix {
    inherit lib;
    inherit wallpaper;
  };
}
